@@ -105,6 +105,7 @@ def _nhsd_apim_auth_token_data(
                 _test_app_credentials["consumerKey"],
                 jwt_private_key_pem,
                 jwt_public_key_id,
+                force_new_token=nhsd_apim_authorization["force_new_token"]
             )
             return token_data
         else:
@@ -127,6 +128,7 @@ def _nhsd_apim_auth_token_data(
             _test_app_callback_url,
             backend_provider_names[access],
             login_form,
+            force_new_token=nhsd_apim_authorization["force_new_token"]
         )
     elif authentication == "separate":
         token_data = get_access_token_via_user_restricted_flow_separate_auth(
@@ -136,6 +138,7 @@ def _nhsd_apim_auth_token_data(
             _test_app_credentials["consumerKey"],
             jwt_private_key_pem,
             jwt_public_key_id,
+            force_new_token=nhsd_apim_authorization["force_new_token"]
         )
     else:
         raise ValueError(f"Invalid authentication: {authentication}")
@@ -148,5 +151,7 @@ def nhsd_apim_auth_headers(
 ):
     if "access_token" in _nhsd_apim_auth_token_data:
         return {"Authorization": f"Bearer {_nhsd_apim_auth_token_data['access_token']}"}
+    elif "apikey" in _nhsd_apim_auth_token_data:
+        return _nhsd_apim_auth_token_data
     return {}
 
